Application lifecycle orchestration: typestate App and startup summary.
Re-exports
pub use app::App;pub use app::AppBuilder;pub use app::Built;pub use app::Started;pub use app::Stopped;pub use app::Unconfigured;pub use hooks::LifecycleEvent;pub use hooks::LifecycleEventType;
Modules
- app
- Typestate
AppandAppBuilder. - component
- Lifecycle-managed component trait and lazy wrapper.
- health
- Health report types.
- hooks
- Lifecycle hook events. Bootstrap lifecycle phase metadata.
- registry
- Ordered component registry with state tracking.
- state
- Component lifecycle states.
Structs
- Cancellation
Token - A token which can be used to signal a cancellation request to one or more tasks.
- Health
- Health report from a single component.
- Lazy
Component - Wraps a component factory so construction is deferred until
start(). - Registry
- Ordered component registry.
- Registry
Config - Configuration for the component registry.
- Stop
Result - Detailed result for an attempted component stop.
Enums
- Health
Status - Liveness state of a component.
- State
- Lifecycle state tracked for each registered component.
Traits
- Component
- Lifecycle-managed infrastructure component.