Module app

Module app 

Typestate App and AppBuilder.

Structs

App
Application orchestrator with typestate lifecycle.
AppBuilder
Builder for App.
Built
Typestate marker for a built application whose components are not running.
Started
Typestate marker for an application with started components.
Stopped
Typestate marker for an application that has completed shutdown.
Unconfigured
Typestate marker retained only as the unbuildable initial marker.