App

Struct App 

pub struct App<S, C> { /* private fields */ }
Application orchestrator with typestate lifecycle.

Valid transitions are compile-time scoped:

AppBuilder::build() -> App<Built, C>
App<Built, C>::start() -> App<Started, C>
App<Started, C>::stop() -> App<Stopped, C>

Implementations

Source

impl<C: AppConfig> App<Built, C>

pub fn builder(config: C) -> AppBuilder<C>

Create an AppBuilder.

Source

impl<C> App<Built, C>

pub fn config(&self) -> Arc<C>

Return a clone of the shared application configuration.

pub fn container(&self) -> Arc<Container>

Return the typed application DI container.

pub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>

Return the bounded lifecycle event bus used by this app.

pub fn shutdown_token(&self) -> CancellationToken

Clone the shutdown token to share with long-running tasks.

pub fn before_start<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called before components start.

pub fn after_start<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called after components start and readiness checks pass.

pub fn before_stop<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called before components stop.

pub fn after_stop<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called after components stop.

Source

impl<C: AppConfig> App<Built, C>

pub async fn start(self) -> AppResult<App<Started, C>>

Start components and transition to Started.

pub async fn run(self) -> AppResult<()>

Run as a long-running service until a signal or shutdown token fires.

pub async fn run_task<F, Fut>(self, task: F) -> AppResult<()>
where F: FnOnce(Arc<C>, CancellationToken) -> Fut, Fut: Future<Output = AppResult<()>>,

Run a finite task after startup, then stop the app.

Source

impl<C> App<Started, C>

pub fn config(&self) -> Arc<C>

Return a clone of the shared application configuration.

pub fn container(&self) -> Arc<Container>

Return the typed application DI container.

pub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>

Return the bounded lifecycle event bus used by this app.

pub fn shutdown_token(&self) -> CancellationToken

Clone the shutdown token to share with long-running tasks.

pub async fn stop(self) -> AppResult<App<Stopped, C>>

Stop components and transition to Stopped.

Source

impl<C> App<Stopped, C>

pub fn config(&self) -> Arc<C>

Return a clone of the shared application configuration.

pub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>

Return the bounded lifecycle event bus used by this app.