AppBuilder

Struct AppBuilder 

pub struct AppBuilder<C: AppConfig> { /* private fields */ }
Builder for App.

The builder is the composition root for configuration validation, component registration, dependency injection, provider registration, and lifecycle hook ordering.

Implementations

Source

impl<C: AppConfig> AppBuilder<C>

pub fn new(config: C) -> Self

Create a new builder with the given application configuration.

pub fn with_graceful_timeout(self, timeout: Duration) -> Self

Set the graceful shutdown timeout.

pub fn with_component(self, component: Arc<dyn Component>) -> Self

Register a component to be started and stopped by the app lifecycle.

pub fn with_container(self, container: Arc<Container>) -> Self

Use an existing typed DI container as the application container.

pub fn with_lifecycle_event_bus( self, lifecycle_events: EventBus<LifecycleEvent>, ) -> Self

Use an existing bounded lifecycle event bus.

pub fn with_dependency<T>(self, dependency: Arc<T>) -> Self
where T: Send + Sync + 'static,

Register a typed dependency in the application DI container.

pub fn with_provider<P>(self, provider: Arc<P>) -> Self
where P: Provider + Send + Sync + 'static,

Register a provider implementation in the application DI container.

pub fn before_start<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called before components start.

pub fn after_start<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called after components start and readiness checks pass.

pub fn before_stop<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called before components stop.

pub fn after_stop<F, Fut>(self, hook: F) -> Self
where F: Fn(CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = AppResult<()>> + Send + 'static,

Register a hook called after components stop.

pub fn build(self) -> AppResult<App<Built, C>>

Validate config and build the application in the Built state.